import React, {useState} from 'react';

import {
  Image,
  Text,
  StyleSheet,
  TouchableOpacity,
  View,
  SafeAreaView,
  Dimensions,
  Modal,
  Button,
} from 'react-native';
import {WebView} from 'react-native-webview';
import LinearGradient from 'react-native-linear-gradient';

import Icon from './Smile-Coin-Logo.png';

const PROD_TARGET = 'https://app.smilecoin.us';
const DEV_TARGET = 'https://app.smilecoin.dev';
const LOCAL_TARGET = 'http://localhost:3000';

const SmileReceiveButton = ({
  amount,
  uuid,
  platform,
  platform_address,
  platform_parameters,
  note,
  callback,
  env,
}) => {
  const SDK_DOMAIN =
    env === 'production'
      ? PROD_TARGET
      : env === 'development'
      ? DEV_TARGET
      : LOCAL_TARGET;

  const isProduction = env === 'production';
  const [webviewOpen, setWebviewOpen] = useState(false);
  const [isProcessed, setIsProcessed] = useState(false);
  const src = `${SDK_DOMAIN}/sdk/transaction?data=${encodeURIComponent(
    JSON.stringify({
      txn_amount: amount,
      uuid,
      platform,
      platform_address,
      platform_parameters,
      note,
    }),
  )}`;

  const styles = StyleSheet.create({
    linearGradient: {
      paddingBottom: 6,
      paddingTop: 6,
      paddingLeft: 5,
      paddingRight: 5,
      display: 'flex',
      flexDirection: 'row',
      alignItems: 'center',
      justifyContent: 'center',
      width: 210,
      borderRadius: 25,
    },
    smiletext: {
      color: '#fff',
      fontWeight: '700',
      marginLeft: 6,
    },
  });

  const messageEventResponseHandler = async event => {
    if (isProcessed) {
      return;
    }
    const data = JSON.parse(event.nativeEvent.data);
    if (data.status === 'success' && data.signed_txn) {
      await setIsProcessed(true);
      setWebviewOpen(false);
      console.log(data);
      await callback(data.signed_txn);
      return setIsProcessed(false);
    }
  };

  let screenHeight = Dimensions.get('window').height;
  let screenWidth = Dimensions.get('window').width;

  return webviewOpen ? (
    <Modal style={{flex: 1, paddingTop: '10pt'}}>
      <SafeAreaView style={{flex: 1, backgroundColor: 'transparent'}}>
        <View
          style={{
            width: '100%',
            display: 'flex',
            alignItems: 'flex-start',
            backgroundColor: '#28cccf',
          }}>
          <Button
            title="< Cancel Transaction"
            color="#fff"
            onPress={() => setWebviewOpen(false)}
          />
        </View>
        <WebView
          style={{flex: 1, height: '80%'}}
          source={{uri: src}}
          onMessage={async event => {
            try {
              messageEventResponseHandler(event);
            } catch (err) {}
          }}
        />
      </SafeAreaView>
    </Modal>
  ) : (
    <SafeAreaView>
      <TouchableOpacity onPress={() => setWebviewOpen(true)}>
        <LinearGradient
          colors={['#21B4A8', '#38CDC5']}
          style={styles.linearGradient}>
          <Image source={Icon} />
          <Text style={styles.smiletext}>{'Pay with Smile Coin'}</Text>
        </LinearGradient>
      </TouchableOpacity>
    </SafeAreaView>
  );
};
export default SmileReceiveButton;
